import React, { useEffect, useRef } from "react";
import Ogma from 'ogma';

import './OgmaWrapper.css';

export default function OgmaWrapper ({ graph, onNodeClick }) {
  const containerId = 'ogma-container';
  // initialize ogma and get a reference to it
  const ogmaRef = useRef(null);
  useEffect(() => {
    ogmaRef.current = new Ogma({ container: containerId });
  }, []);

  // setup events and more
  useEffect(() => {
    // as suggested by react debug tools, due to ref lifecycle
    const ogma = ogmaRef.current;
    const clickHandler = ({ target }) => {
      if (target && target.isNode) {
        onNodeClick(target.getId());
      } else {
        onNodeClick(null);
      }
    };

    ogma.events.onClick(clickHandler);
    return () => ogma.events.removeListener(clickHandler);
  }, [onNodeClick]);

  // update graph
  useEffect(() => {
    const nodeSettings = { attributes: ['x', 'y', 'radius' ] };
    const edgeSettings = { attributes: ['width' ] };
    ogmaRef.current.clearGraph();
    ogmaRef.current.setGraph(graph)
      .then(() => ogmaRef.current.layouts.forceLink({ locate: graph.nodes.length !== 0 }))
      // primitive tracking of the current attributes
      // this is where you can send the updates to your state management,
      // e.g. redux, etc
      .then(() => {
        graph.nodes = ogmaRef.current.getNodes().toJSON(nodeSettings);
        graph.edges = ogmaRef.current.getEdges().toJSON(edgeSettings);
      });
    },
    [graph]
  );

  return (
  <div className="OgmaWrapper">
    <div id={containerId} />
  </div>
  );
}
